@@ -21,6 +21,7 @@ public class CSSHelper extends HelperBase {
     /**  @since 0.9.33 moved from ConfigUIHelper */
     public static final String PROP_THEME_PFX = PROP_THEME_NAME + '.';
     public static final String DEFAULT_THEME = "light";
+    public static final String ALT_THEME = "dark";
     public static final String BASE_THEME_PATH = "/themes/console/";
     private static final String FORCE = "classic";
     public static final String PROP_REFRESH = "routerconsole.summaryRefresh";
@@ -68,6 +69,16 @@ public class CSSHelper extends HelperBase {
         return url;
     }
 
+    /**
+     * So we don't have to refresh after saving. Called from css.jsi.
+     * @since 0.9.52
+     */
+    public void setTheme(String theme) {
+        if (theme != null && theme.length() > 0 &&
+            theme.replaceAll("[a-zA-Z0-9_-]", "").length() == 0)
+            _context.router().saveConfig(PROP_THEME_NAME, theme);
+    }
+
     /**
      * Returns whether app embedding is enabled or disabled
      * @since 0.9.32
